v0.6.1 (2025-05-11)
-------------------
- Update for click v8.2.0

v0.6.0 (2025-02-11)
-------------------
- Add support for asyncclick (contributed by
  [@kquinsland](https://github.com/kquinsland))

v0.5.1 (2024-12-01)
-------------------
- Migrated from setuptools to hatch
- Drop support for Python 3.7
- Support Python 3.13

v0.5.0 (2023-10-09)
-------------------
- Support Python 3.10, 3.11, and 3.12
- Drop support for Python 3.6
- Require Click >= 8.0
- Add type annotations
- Remove `LogLevelType` alias

v0.4.0.post1 (2021-06-05)
-------------------------
- Update docs to mention shell completion

v0.4.0 (2021-06-05)
-------------------
- Support & test against Click 8
- Support shell completion in Click 8

v0.3.0 (2021-02-10)
-------------------
- Support & test against Click 6
- Support custom log levels

v0.2.0 (2021-02-02)
-------------------
- Renamed the class from `LogLevelType` to `LogLevel`.  The old name is still
  available (for now) as an alias.

v0.1.0 (2021-02-01)
-------------------
Initial release
